sievetools.all_are_residue_class_expressions
============================================

.. autofunction:: abjad.tools.sievetools.all_are_residue_class_expressions.all_are_residue_class_expressions
